# Copyright (C) 2020-2024 Soleta Networks <opengnsys@soleta.eu>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the
# Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.

import argparse

from cli.utils import *

class OgRepo():

    @staticmethod
    def list_repos(rest):
        r = rest.get('/repositories')
        print_json(r.text)

    @staticmethod
    def add_repo(rest, args):
        parser = argparse.ArgumentParser(prog='ogcli add repo')
        parser.add_argument('--address',
                            nargs='?',
                            required=True,
                            help='valid ip address')
        parser.add_argument('--name',
                            nargs='?',
                            required=True,
                            help='valid ip address')
        parser.add_argument('--center',
                            nargs='?',
                            type=int,
                            help='(Optional, Legacy) Center id serving this repository')
        parsed_args = parser.parse_args(args)
        payload = {
            'ip': parsed_args.address,
            'name': parsed_args.name,
        }
        if parsed_args.center:
            payload['center']: center

        rest.post('/repository/add', payload=payload)

    @staticmethod
    def delete_repo(rest, args):
        parser = argparse.ArgumentParser(prog='ogcli delete repo')
        parser.add_argument('--id',
                            type=int,
                            nargs='?',
                            required=True,
                            help='repo id (list repos using "ogcli list repos")')
        parsed_args = parser.parse_args(args)
        payload = {'id': parsed_args.id}
        rest.post('/repository/delete', payload=payload)

    @staticmethod
    def set_repo(rest, args):
        parser = argparse.ArgumentParser(prog='ogcli set repo')
        parser.add_argument('--id',
                            type=int,
                            nargs='?',
                            required=True,
                            help='repo id (list repos using "ogcli list repos")')
        group = parser.add_argument_group('clients', 'Target client arguments')
        group.add_argument('--room-id',
                           type=int,
                           action='append',
                           default=[],
                           required=False,
                           help='Clients from a given room id')
        group.add_argument('--client-ip',
                           action='append',
                           default=[],
                           required=False,
                           help='Any valid client ip address')
        parsed_args = parser.parse_args(args)

        r = rest.get('/scopes')
        scopes = r.json()
        ips = set()

        for room in parsed_args.room_id:
            room_scope = scope_lookup(room, 'room', scopes)
            ips.update(ips_in_scope(room_scope))
        for l in parsed_args.client_ip:
            ips.add(l)
        if not ips:
            print('No valid clients specified.')
            return

        payload = {'id': parsed_args.id, 'clients': list(ips)}
        rest.post('/client/repo', payload=payload)
