# Copyright (C) 2020-2024 Soleta Networks <opengnsys@soleta.eu>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the
# Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.

import argparse

from cli.utils import *

class OgServer():

    @staticmethod
    def list_servers(rest):
        r = rest.get('/server')
        print_json(r.text)

    @staticmethod
    def add_server(rest, args):
        parser = argparse.ArgumentParser(prog='ogcli add server')
        parser.add_argument('--address',
                            nargs='?',
                            required=True,
                            help='valid ogserver ip address')
        parsed_args = parser.parse_args(args)
        payload = {'address': parsed_args.address}
        rest.post('/server', payload=payload)

    @staticmethod
    def delete_server(rest, args):
        parser = argparse.ArgumentParser(prog='ogcli delete server')
        parser.add_argument('--id',
                            type=int,
                            nargs='?',
                            required=True,
                            help='server id in the database')
        parsed_args = parser.parse_args(args)
        payload = {'id': parsed_args.id}
        rest.delete('/server', payload=payload)

    @staticmethod
    def set_server(rest, args):
        parser = argparse.ArgumentParser(prog='ogcli set server')
        parser.add_argument('--id',
                            type=int,
                            nargs='?',
                            required=True,
                            help='server id in the database')
        group = parser.add_argument_group('clients', 'Client selection args')
        group.add_argument('--room-id',
                           type=int,
                           action='append',
                           default=[],
                           required=False,
                           help='Clients from given room id')
        group.add_argument('--client-ip',
                           action='append',
                           default=[],
                           required=False,
                           help='Any valid client IP')
        parsed_args = parser.parse_args(args)

        r = rest.get('/scopes')
        scopes = r.json()
        ips = set()

        for room in parsed_args.room_id:
            room_scope = scope_lookup(room, 'room', scopes)
            ips.update(ips_in_scope(room_scope))
        for l in parsed_args.client_ip:
            ips.add(l)
        if not ips:
            print('Missing --client-ip or --room-id. No clients provided.')
            return

        payload = {'id': parsed_args.id, 'clients': list(ips)}
        rest.post('/client/server', payload=payload)
